@@ -188,9 +188,7 @@ summary.designkey <- function(object,show="dtbw", save="k", ...){
 } ## end summary.designkey
 
 ##--------------------------------------------------------------------------
-setMethod("summary", signature(object="designkey"),
-          definition=summary.designkey)
-##--------------------------------------------------------------------------
+
 # "show.designkey" 
 # Print the design key matrices of an object of class designkey
 #
@@ -318,6 +316,3 @@ alias.designkey <- function(object, model, ...){
 } ## end alias.designkey
 
 ##--------------------------------------------------------------------------
-setMethod("alias", signature(object="designkey"),
-          definition=alias.designkey)
-##--------------------------------------------------------------------------
